==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/ObjectIdentityResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for ObjectIdentity
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class ObjectIdentityResponseProjection extends GraphQLResponseProjection {

    public ObjectIdentityResponseProjection() {
    }

    @Override
    public ObjectIdentityResponseProjection all$() {
        return all$(3);
    }

    @Override
    public ObjectIdentityResponseProjection all$(int maxDepth) {
        this.resourceId();
        this.resourceType();
        this.typename();
        return this;
    }

    public ObjectIdentityResponseProjection resourceId() {
        return resourceId(null);
    }

    public ObjectIdentityResponseProjection resourceId(String alias) {
        fields.add(new GraphQLResponseField("resourceId").alias(alias));
        return this;
    }

    public ObjectIdentityResponseProjection resourceType() {
        return resourceType(null);
    }

    public ObjectIdentityResponseProjection resourceType(String alias) {
        fields.add(new GraphQLResponseField("resourceType").alias(alias));
        return this;
    }

    public ObjectIdentityResponseProjection typename() {
        return typename(null);
    }

    public ObjectIdentityResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/ObjectIdentityResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for ObjectIdentity
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class ObjectIdentityResponseProjection extends GraphQLResponseProjection {

    public ObjectIdentityResponseProjection() {
    }

    @Override
    public ObjectIdentityResponseProjection all$() {
        return all$(3);
    }

    @Override
    public ObjectIdentityResponseProjection all$(int maxDepth) {
        this.resourceId();
        this.resourceType();
        this.typename();
        return this;
    }

    public ObjectIdentityResponseProjection resourceId() {
        return resourceId(null);
    }

    public ObjectIdentityResponseProjection resourceId(String alias) {
        fields.add(new GraphQLResponseField("resourceId").alias(alias));
        return this;
    }

    public ObjectIdentityResponseProjection resourceType() {
        return resourceType(null);
    }

    public ObjectIdentityResponseProjection resourceType(String alias) {
        fields.add(new GraphQLResponseField("resourceType").alias(alias));
        return this;
    }

    public ObjectIdentityResponseProjection typename() {
        return typename(null);
    }

    public ObjectIdentityResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}
